diff --git a/source/distro/changelog.txt b/source/distro/changelog.txt
index 5bedea1..63d5dde 100644
--- a/source/distro/changelog.txt
+++ b/source/distro/changelog.txt
@@ -2,6 +2,12 @@ Changelog for Writer2LaTeX version 1.4 -> 1.6
---------- version 1.5.3 ----------
+[w2l] The command \textsubscript is now defined with \providecommand to avoid problems with other packages that may
+ already have defined this command
+
+[w2l] Added basic support for hebrew (XeTeX backend only). If the default CTL language is hebrew the entire document
+ is exported with hebrew language setting with a suitable default font (Frank Ruehl CLM/Nachlieli CLM/Miriam Mono CLM)
+
[w2x] In EPUB the title must be non-empty. To avoid creating an invalid EPUB, the file name is now used as title
if the title is empty.
diff --git a/source/java/writer2latex/api/ConverterFactory.java b/source/java/writer2latex/api/ConverterFactory.java
index 375cc0b..8708146 100644
--- a/source/java/writer2latex/api/ConverterFactory.java
+++ b/source/java/writer2latex/api/ConverterFactory.java
@@ -20,7 +20,7 @@
*
* All Rights Reserved.
*
- * Version 1.6 (2015-06-23)
+ * Version 1.6 (2015-07-01)
*
*/
@@ -33,7 +33,7 @@ public class ConverterFactory {
// Version information
private static final String VERSION = "1.5.3";
- private static final String DATE = "2015-06-23";
+ private static final String DATE = "2015-07-01";
/** Return the Writer2LaTeX version in the form
* (major version).(minor version).(patch level)
diff --git a/source/java/writer2latex/epub/OPFWriter.java b/source/java/writer2latex/epub/OPFWriter.java
index dd1a4e0..8c6f511 100644
--- a/source/java/writer2latex/epub/OPFWriter.java
+++ b/source/java/writer2latex/epub/OPFWriter.java
@@ -95,7 +95,7 @@ public class OPFWriter extends DOMDocument {
// Title and language (required; use file name if title is empty)
String sTitle = cr.getMetaData().getTitle();
- appendElement(contentDOM, metadata, "dc:title", sTitle.length()>0 ? sTitle : sFileName);
+ appendElement(contentDOM, metadata, "dc:title", sTitle.trim().length()>0 ? sTitle : sFileName);
appendElement(contentDOM, metadata, "dc:language", cr.getMetaData().getLanguage());
// Modification (required in EPUB 3)
diff --git a/source/java/writer2latex/latex/CharStyleConverter.java b/source/java/writer2latex/latex/CharStyleConverter.java
index cae32e2..a96cab0 100644
--- a/source/java/writer2latex/latex/CharStyleConverter.java
+++ b/source/java/writer2latex/latex/CharStyleConverter.java
@@ -16,11 +16,11 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
* MA 02111-1307 USA
*
- * Copyright: 2002-2010 by Henrik Just
+ * Copyright: 2002-2015 by Henrik Just
*
* All Rights Reserved.
*
- * Version 1.2 (2010-11-28)
+ * Version 1.6 (2015-06-30)
*
*/
@@ -77,7 +77,7 @@ public class CharStyleConverter extends StyleConverter {
pack.append("\\usepackage[normalem]{ulem}").nl();
}
if (bNeedSubscript && !config.getTextAttributeStyleMap().contains("subscript")) {
- decl.append("\\newcommand\\textsubscript[1]{\\ensuremath{{}_{\\text{#1}}}}").nl();
+ decl.append("\\providecommand\\textsubscript[1]{\\ensuremath{{}_{\\text{#1}}}}").nl();
}
if (!styleNames.isEmpty()) {
decl.append("% Text styles").nl().append(declarations);
diff --git a/source/java/writer2latex/latex/i18n/XeTeXI18n.java b/source/java/writer2latex/latex/i18n/XeTeXI18n.java
index 3c79c5a..753cf1d 100644
--- a/source/java/writer2latex/latex/i18n/XeTeXI18n.java
+++ b/source/java/writer2latex/latex/i18n/XeTeXI18n.java
@@ -16,11 +16,11 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
* MA 02111-1307 USA
*
- * Copyright: 2002-2014 by Henrik Just
+ * Copyright: 2002-2015 by Henrik Just
*
* All Rights Reserved.
*
- * Version 1.4 (2014-09-16)
+ * Version 1.6 (2015-06-30)
*
*/
@@ -39,8 +39,10 @@ import writer2latex.latex.util.BeforeAfter;
public class XeTeXI18n extends I18n {
private Polyglossia polyglossia;
- private boolean bUsePolyglossia;
+ private boolean bLTR;
private boolean bUseXepersian;
+ private String sLTRCommand=null;
+ private String sRTLCommand=null;
/** Construct a new XeTeXI18n as ConverterHelper
* @param ofr the OfficeReader to get language information from
@@ -49,16 +51,27 @@ public class XeTeXI18n extends I18n {
*/
public XeTeXI18n(OfficeReader ofr, LaTeXConfig config, ConverterPalette palette) {
super(ofr,config,palette);
- polyglossia = new Polyglossia();
- polyglossia.applyLanguage(sDefaultLanguage, sDefaultCountry);
- // Currently all languages except farsi (fa_IR) are handled with polyglossia
- // Actually only LTR languages are supported as yet
- // TODO: Support CTL languages using polyglossia
- bUsePolyglossia = !"fa".equals(sDefaultCTLLanguage);
- // For farsi, we load xepersian.sty
+ // CTL support: Currently two CTL languages are supported
+ // - hebrew (he_IL) using polyglossia.sty
+ // - farsi (fa_IR) using xepersian.sty
// TODO: Add a use_xepersian option, using polyglossia if false
- bUseXepersian = !bUsePolyglossia;
+ // For these languages currently only monolingual documents are supported
+ // For LTR languages, multilingual documents are supported using polyglossia
+ polyglossia = new Polyglossia();
+ bLTR = !"fa".equals(sDefaultCTLLanguage) && !"he".equals(sDefaultCTLLanguage);
+ if (bLTR) {
+ polyglossia.applyLanguage(sDefaultLanguage, sDefaultCountry);
+ }
+ else {
+ polyglossia.applyLanguage(sDefaultCTLLanguage, sDefaultCTLCountry);
+ }
+ // For farsi, we load xepersian.sty
+ bUseXepersian = "fa".equals(sDefaultCTLLanguage);
+ if (bUseXepersian) {
+ sLTRCommand = "\\lr";
+ sRTLCommand = "\\rl";
+ }
}
/** Add declarations to the preamble to load the required packages
@@ -70,24 +83,29 @@ public class XeTeXI18n extends I18n {
.append("\\usepackage{fontspec}").nl()
.append("\\usepackage{xunicode}").nl()
.append("\\usepackage{xltxtra}").nl();
- if (bUsePolyglossia) {
+ // xepersian.sty and polyglossia (or rather bidi) should be loaded as the last package
+ // We put it them the declarations part to achieve this
+ if (!bUseXepersian) {
String[] polyglossiaDeclarations = polyglossia.getDeclarations();
for (String s: polyglossiaDeclarations) {
- pack.append(s).nl();
+ decl.append(s).nl();
+ }
+ if (!bLTR) { // Use a default font set for hebrew
+ decl.append("\\setmainfont[Script=Hebrew]{Frank Ruehl CLM}").nl();
+ decl.append("\\setsansfont[Script=Hebrew]{Nachlieli CLM}").nl();
+ decl.append("\\setmonofont[Script=Hebrew]{Miriam Mono CLM}").nl();
}
}
- else if (bUseXepersian) {
- // xepersian.sty must be loaded as the last package
- // We put it in the declarations part to achieve this
+ else {
decl.append("\\usepackage{xepersian}").nl();
- // Set the default font to the default CTL font defined in the document
- StyleWithProperties defaultStyle = ofr.getDefaultParStyle();
- if (defaultStyle!=null) {
- String sDefaultCTLFont = defaultStyle.getProperty(XMLString.STYLE_FONT_NAME_COMPLEX);
- if (sDefaultCTLFont!=null) {
- decl.append("\\settextfont{").append(sDefaultCTLFont).append("}").nl();
- }
- }
+ // Set the default font to the default CTL font defined in the document
+ StyleWithProperties defaultStyle = ofr.getDefaultParStyle();
+ if (defaultStyle!=null) {
+ String sDefaultCTLFont = defaultStyle.getProperty(XMLString.STYLE_FONT_NAME_COMPLEX);
+ if (sDefaultCTLFont!=null) {
+ decl.append("\\settextfont{").append(sDefaultCTLFont).append("}").nl();
+ }
+ }
}
}
@@ -98,7 +116,7 @@ public class XeTeXI18n extends I18n {
* @param ba the BeforeAfter
to add LaTeX code to.
*/
public void applyLanguage(StyleWithProperties style, boolean bDecl, boolean bInherit, BeforeAfter ba) {
- if (bUsePolyglossia && !bAlwaysUseDefaultLang && style!=null) {
+ if (bLTR && !bAlwaysUseDefaultLang && style!=null) {
// TODO: Support CTL and CJK
String sISOLang = style.getProperty(XMLString.FO_LANGUAGE,bInherit);
String sISOCountry = style.getProperty(XMLString.FO_COUNTRY, bInherit);
@@ -143,7 +161,7 @@ public class XeTeXI18n extends I18n {
convert(s.charAt(i),buf);
}
}
- else if (bUsePolyglossia) {
+ else if (!bUseXepersian) {
int i = 0;
while (inCurrentLevel) {
if (nLevel%2==0) { // even is LTR
- buf.append("\\lr{");
+ buf.append(sLTRCommand).append("{");
}
else { // odd is RTL
- buf.append("\\rl{");
+ buf.append(sRTLCommand).append("{");
}
nCurrentLevel=nLevel;
nNestingLevel++;